@@ -1,23 +1,23 @@
 /*
-* Copyright (C) 2010 Andreas Scherf <ascherfy@gmail.com>
-*
-* This file is part of the KDE project "KBounce"
-*
-* KBounce is free software; you can redistribute it and/or
-* modify it under the terms of the GNU Library General Public
-* License as published by the Free Software Foundation; either
-* version 2 of the License, or (at your option) any later version.
-*
-* KBounce is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-* Library General Public License for more details.
-*
-* You should have received a copy of the GNU Library General Public
-* License along with KBounce; if not, write to the Free
-* Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-* Boston, MA  02110-1301, USA.
-*/
+ * Copyright (C) 2010 Andreas Scherf <ascherfy@gmail.com>
+ *
+ * This file is part of the KDE project "KBounce"
+ *
+ * KBounce is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * KBounce is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with KBounce; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
+ */
 
 #include "backgroundselector.h"
 #include "ui_backgroundselector.h"
@@ -47,11 +47,11 @@ void BackgroundSelector::changeEvent(QEvent *e)
 {
     QWidget::changeEvent(e);
     switch (e->type()) {
-    case QEvent::LanguageChange:
-        ui->retranslateUi(this);
-        break;
-    default:
-        break;
+        case QEvent::LanguageChange:
+            ui->retranslateUi(this);
+            break;
+        default:
+            break;
     }
 }
 
@@ -69,8 +69,8 @@ void BackgroundSelector::setupData()
         KConfig * config = m_config->config();
         KConfigGroup group = config->group("General");
         QString picturePath = group.readPathEntry("BackgroundPicturePath",QDir::homePath() );
-        ui->kurlrequester->setUrl(picturePath);
-        ui->kurlrequester->setStartDir(picturePath);
+        ui->kurlrequester->setUrl(QUrl(picturePath));
+        ui->kurlrequester->setStartDir(QUrl(picturePath));
     }
 }
 
